define(
//begin v1.x content
({
	widgetLabel: "Dávková kontrola pravopisu",
	unfound: "Nenalezeno",
	skip: "Přeskočit",
	skipAll: "Přeskočit vše",
	toDic: "Přidat do slovníku",
	suggestions: "Návrhy",
	replace: "Nahradit",
	replaceWith: "Text pro nahrazení",
	replaceAll: "Nahradit vše",
	cancel: "Storno",
	msg: "Nebyly nalezeny žádné chyby pravopisu.",
	iSkip: "Přeskočit tento výskyt",
	iSkipAll: "Přeskočit všechny podobné výskyty",
	iMsg: "Žádné návrhy pravopisu"
})

//end v1.x content
);
